import { type Extension, StateField } from "@codemirror/state";
import { type Command, type DecorationSet } from "@codemirror/view";
import { type AiOptions } from "./state.js";
/**
 * Creates an AI-assisted editing extension for CodeMirror.
 *
 * @param opts - Configuration options for the AI extension
 * @returns Array of CodeMirror extensions
 * @throws {Error} If required options are missing or invalid
 *
 * Key Features:
 * - AI-assisted code editing with customizable prompts
 * - Keyboard shortcuts for all operations
 * - Undo/redo support
 * - Loading states and error handling
 * - Accessibility support
 * - Input validation and sanitization
 *
 * Usage:
 * ```ts
 * const view = new EditorView({
 *   extensions: [
 *     aiExtension({
 *       prompt: async ({prompt, selection}) => {
 *         // Generate completion
 *         return newCode;
 *       },
 *       onError: (error) => console.error(error)
 *     })
 *   ]
 * });
 * ```
 */
export declare function aiExtension(options: AiOptions): Extension[];
/**
 * Track line shifts and adjust the position of the input.
 */
export declare const lineShiftListener: Extension;
/**
 * Tooltip visibility listener. This will hide the tooltip
 * if the user hasn't selected a block of text.
 */
export declare const tooltipVisibilityListener: Extension;
/** Decoration for the new code (green) */
export declare const newCodeDecoration: Extension;
/** Decoration for the input prompt */
export declare const inputPromptDecoration: Extension;
/**
 * Decoration highlighting old code with red
 */
export declare const oldCodeDecoration: StateField<DecorationSet>;
/** Command to show the input prompt */
export declare const showAiEditInput: Command;
/** Command to close the input prompt */
export declare const closeAiEditInput: Command;
/** Command to accept the completion */
export declare const acceptAiEdit: Command;
/** Command to reject the completion */
export declare const rejectAiEdit: Command;
//# sourceMappingURL=inline-edit.d.ts.map